You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/12 08:14:44 UTC

[06/64] [abbrv] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperLoadTest1.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask2.java b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask2.java
index cd34c2c..3b78a0e 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask2.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask2.java
@@ -29,7 +29,7 @@ public class GridContinuousMapperTask2 extends ComputeTaskAdapter<int[], Integer
 
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable int[] jobIds)
-        throws GridException {
+        throws IgniteCheckedException {
         Map<ComputeJob, ClusterNode> mappings = new HashMap<>(jobIds.length);
 
         Iterator<ClusterNode> nodeIter = g.cluster().forRemotes().nodes().iterator();
@@ -63,7 +63,7 @@ public class GridContinuousMapperTask2 extends ComputeTaskAdapter<int[], Integer
     }
 
     /** {@inheritDoc} */
-    @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd) throws GridException {
+    @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd) throws IgniteCheckedException {
         TestObject o = res.getData();
 
         X.println("Received job result from node [resId=" + o.getId() + ", node=" + res.getNode().id() + ']');
@@ -72,7 +72,7 @@ public class GridContinuousMapperTask2 extends ComputeTaskAdapter<int[], Integer
     }
 
     /** {@inheritDoc} */
-    @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         X.println(">>> Reducing task...");
 
         return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridNodeStartup.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTask.java b/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTask.java
index 8db9c28..9795503 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTask.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTask.java
@@ -54,7 +54,7 @@ public class GridMergeSortLoadTask extends ComputeTaskSplitAdapter<int[], int[]>
                 // Task execution result future.
                 private ComputeTaskFuture<int[]> fut;
 
-                @Override public Object execute() throws GridException {
+                @Override public Object execute() throws IgniteCheckedException {
                     if (arr.length == 1)
                         return arr;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/streamer/EventClosure.java b/modules/core/src/test/java/org/gridgain/loadtests/streamer/EventClosure.java
index d5d00b3..c0eec6d 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/streamer/EventClosure.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/streamer/EventClosure.java
@@ -31,7 +31,7 @@ class EventClosure implements IgniteInClosure<IgniteStreamer> {
             try {
                 streamer.addEvent(rnd.nextInt(rndRange));
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 X.println("Failed to add streamer event: " + e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java b/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
index b4ae960..a84268b 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.loadtests.streamer;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.streamer.index.*;
 import org.apache.ignite.streamer.index.hash.*;
@@ -107,7 +108,7 @@ public class GridStreamerIndexLoadTest {
         final AtomicLong enqueueCntr = new AtomicLong();
 
         IgniteFuture<Long> enqueueFut = runMultiThreadedAsync(new CAX() {
-            @Override public void applyx() throws GridException {
+            @Override public void applyx() throws IgniteCheckedException {
                 Random rnd = new Random();
 
                 while (!Thread.currentThread().isInterrupted()) {
@@ -121,7 +122,7 @@ public class GridStreamerIndexLoadTest {
         final AtomicLong evictCntr = new AtomicLong();
 
         IgniteFuture<Long> evictFut = runMultiThreadedAsync(new CAX() {
-            @Override public void applyx() throws GridException {
+            @Override public void applyx() throws IgniteCheckedException {
                 while (!Thread.currentThread().isInterrupted()) {
                     win.pollEvicted();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/streamer/average/TestStage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/streamer/average/TestStage.java b/modules/core/src/test/java/org/gridgain/loadtests/streamer/average/TestStage.java
index 03ae9db..686d258 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/streamer/average/TestStage.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/streamer/average/TestStage.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.loadtests.streamer.average;
 
+import org.apache.ignite.*;
 import org.apache.ignite.streamer.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 
 import java.util.*;
@@ -27,7 +27,7 @@ class TestStage implements StreamerStage<Integer> {
 
     /** {@inheritDoc} */
     @Override public Map<String, Collection<?>> run(StreamerContext ctx, Collection<Integer> evts)
-        throws GridException {
+        throws IgniteCheckedException {
         ConcurrentMap<String, TestAverage> loc = ctx.localSpace();
 
         TestAverage avg = loc.get("avg");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/swap/GridSwapEvictAllBenchmark.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/testframework/GridSpiTestContext.java b/modules/core/src/test/java/org/gridgain/testframework/GridSpiTestContext.java
index 679976f..dee0951 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/GridSpiTestContext.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/GridSpiTestContext.java
@@ -9,16 +9,16 @@
 
 package org.gridgain.testframework;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
-import org.gridgain.grid.kernal.managers.communication.*;
-import org.gridgain.grid.kernal.managers.eventstorage.*;
 import org.apache.ignite.plugin.security.*;
+import org.apache.ignite.spi.*;
 import org.apache.ignite.spi.discovery.*;
 import org.apache.ignite.spi.swapspace.*;
+import org.gridgain.grid.kernal.managers.communication.*;
+import org.gridgain.grid.kernal.managers.eventstorage.*;
 import org.gridgain.grid.util.direct.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
@@ -359,7 +359,7 @@ public class GridSpiTestContext implements IgniteSpiContext {
     }
 
     /** {@inheritDoc} */
-    @Override public <K, V> V get(String cacheName, K key) throws GridException {
+    @Override public <K, V> V get(String cacheName, K key) throws IgniteCheckedException {
         assert cacheName != null;
         assert key != null;
 
@@ -380,7 +380,7 @@ public class GridSpiTestContext implements IgniteSpiContext {
     }
 
     /** {@inheritDoc} */
-    @Override public <K, V> V put(String cacheName, K key, V val, long ttl) throws GridException {
+    @Override public <K, V> V put(String cacheName, K key, V val, long ttl) throws IgniteCheckedException {
         assert cacheName != null;
         assert key != null;
         assert ttl >= 0;
@@ -398,7 +398,7 @@ public class GridSpiTestContext implements IgniteSpiContext {
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked"})
-    @Override public <K, V> V putIfAbsent(String cacheName, K key, V val, long ttl) throws GridException {
+    @Override public <K, V> V putIfAbsent(String cacheName, K key, V val, long ttl) throws IgniteCheckedException {
         V v = get(cacheName, key);
 
         if (v != null)
@@ -408,7 +408,7 @@ public class GridSpiTestContext implements IgniteSpiContext {
     }
 
     /** {@inheritDoc} */
-    @Override public <K, V> V remove(String cacheName, K key) throws GridException {
+    @Override public <K, V> V remove(String cacheName, K key) throws IgniteCheckedException {
         assert cacheName != null;
         assert key != null;
 
@@ -429,7 +429,7 @@ public class GridSpiTestContext implements IgniteSpiContext {
         try {
             res =  get(cacheName, key) != null;
         }
-        catch (GridException ignored) {
+        catch (IgniteCheckedException ignored) {
 
         }
 
@@ -438,31 +438,31 @@ public class GridSpiTestContext implements IgniteSpiContext {
 
     /** {@inheritDoc} */
     @Override public void writeToSwap(String spaceName, Object key, @Nullable Object val,
-        @Nullable ClassLoader ldr) throws GridException {
+        @Nullable ClassLoader ldr) throws IgniteCheckedException {
         /* No-op. */
     }
 
     /** {@inheritDoc} */
     @Override public <T> T readFromSwap(String spaceName, SwapKey key, @Nullable ClassLoader ldr)
-        throws GridException {
+        throws IgniteCheckedException {
         return null;
     }
 
     /** {@inheritDoc} */
     @Override public <T> T readFromOffheap(String spaceName, int part, Object key, byte[] keyBytes,
-        @Nullable ClassLoader ldr) throws GridException {
+        @Nullable ClassLoader ldr) throws IgniteCheckedException {
         return null;
     }
 
     /** {@inheritDoc} */
     @Override public boolean removeFromOffheap(@Nullable String spaceName, int part, Object key,
-        @Nullable byte[] keyBytes) throws GridException {
+        @Nullable byte[] keyBytes) throws IgniteCheckedException {
         return false;
     }
 
     /** {@inheritDoc} */
     @Override public void writeToOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes,
-        Object val, @Nullable byte[] valBytes, @Nullable ClassLoader ldr) throws GridException {
+        Object val, @Nullable byte[] valBytes, @Nullable ClassLoader ldr) throws IgniteCheckedException {
         // No-op.
     }
 
@@ -473,7 +473,7 @@ public class GridSpiTestContext implements IgniteSpiContext {
 
     /** {@inheritDoc} */
     @Override public void removeFromSwap(String spaceName, Object key,
-        @Nullable ClassLoader ldr) throws GridException {
+        @Nullable ClassLoader ldr) throws IgniteCheckedException {
         // No-op.
     }
 
@@ -493,18 +493,18 @@ public class GridSpiTestContext implements IgniteSpiContext {
     }
 
     /** {@inheritDoc} */
-    @Override public Collection<GridSecuritySubject> authenticatedSubjects() throws GridException {
+    @Override public Collection<GridSecuritySubject> authenticatedSubjects() throws IgniteCheckedException {
         return Collections.emptyList();
     }
 
     /** {@inheritDoc} */
-    @Override public GridSecuritySubject authenticatedSubject(UUID subjId) throws GridException {
+    @Override public GridSecuritySubject authenticatedSubject(UUID subjId) throws IgniteCheckedException {
         return null;
     }
 
     /** {@inheritDoc} */
     @Nullable @Override public <T> T readValueFromOffheapAndSwap(@Nullable String spaceName, Object key,
-        @Nullable ClassLoader ldr) throws GridException {
+        @Nullable ClassLoader ldr) throws IgniteCheckedException {
         return null;
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
index e6881e0..8a69763 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
@@ -29,13 +29,13 @@ public class GridCacheDeploymentTestTask1 extends ComputeTaskAdapter<ClusterNode
 
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid,
-        @Nullable ClusterNode node) throws GridException {
+        @Nullable ClusterNode node) throws IgniteCheckedException {
         return F.asMap(
             new ComputeJobAdapter() {
                 @IgniteInstanceResource
                 private Ignite ignite;
 
-                @Override public Object execute() throws GridException {
+                @Override public Object execute() throws IgniteCheckedException {
                     X.println("Executing GridCacheDeploymentTestTask1 job on node " +
                         ignite.cluster().localNode().id());
 
@@ -52,7 +52,7 @@ public class GridCacheDeploymentTestTask1 extends ComputeTaskAdapter<ClusterNode
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return null;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask2.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask2.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask2.java
index 1963b63..0264e06 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask2.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask2.java
@@ -25,7 +25,7 @@ import java.util.*;
 public class GridCacheDeploymentTestTask2 extends ComputeTaskAdapter<ClusterNode, Object> {
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid,
-        @Nullable ClusterNode node) throws GridException {
+        @Nullable ClusterNode node) throws IgniteCheckedException {
         return F.asMap(
             new ComputeJobAdapter() {
                 @IgniteInstanceResource
@@ -43,7 +43,7 @@ public class GridCacheDeploymentTestTask2 extends ComputeTaskAdapter<ClusterNode
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return null;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask3.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask3.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask3.java
index 553e7ab..f70e4c8 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask3.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask3.java
@@ -25,7 +25,7 @@ import java.util.*;
 public class GridCacheDeploymentTestTask3 extends ComputeTaskAdapter<T2<ClusterNode, String>, Object> {
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid,
-        @Nullable T2<ClusterNode, String> tup) throws GridException {
+        @Nullable T2<ClusterNode, String> tup) throws IgniteCheckedException {
         final String val = tup.getValue();
 
         return F.asMap(
@@ -33,7 +33,7 @@ public class GridCacheDeploymentTestTask3 extends ComputeTaskAdapter<T2<ClusterN
                     @IgniteInstanceResource
                     private Ignite ignite;
 
-                    @Override public Object execute() throws GridException {
+                    @Override public Object execute() throws IgniteCheckedException {
                         X.println("Executing GridCacheDeploymentTestTask3 job on node " +
                                 ignite.cluster().localNode().id());
 
@@ -48,7 +48,7 @@ public class GridCacheDeploymentTestTask3 extends ComputeTaskAdapter<T2<ClusterN
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return null;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask1.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask1.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask1.java
index a1fafdc..9cc627c 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask1.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask1.java
@@ -23,12 +23,12 @@ import java.util.*;
  */
 public class GridP2PContinuousDeploymentTask1 extends ComputeTaskSplitAdapter<Object, Object> {
     /** {@inheritDoc} */
-    @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+    @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
         return Collections.singleton(new ComputeJobAdapter() {
             @IgniteInstanceResource
             private Ignite ignite;
 
-            @Override public Object execute() throws GridException {
+            @Override public Object execute() throws IgniteCheckedException {
                 X.println(">>> Executing GridP2PContinuousDeploymentTask1 job.");
 
                 ignite.cache(null).putx("key", new GridTestUserResource());
@@ -39,7 +39,7 @@ public class GridP2PContinuousDeploymentTask1 extends ComputeTaskSplitAdapter<Ob
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return null;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask2.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask2.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask2.java
index 495ece0..3b136fc 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask2.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PContinuousDeploymentTask2.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.tests.p2p;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
@@ -21,7 +22,7 @@ import java.util.*;
  */
 public class GridP2PContinuousDeploymentTask2 extends ComputeTaskSplitAdapter<Object, Object> {
     /** {@inheritDoc} */
-    @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+    @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
         return Collections.singleton(new ComputeJobAdapter() {
             @Override public Object execute() {
                 X.println(">>> Executing GridP2PContinuousDeploymentTask2 job.");
@@ -32,7 +33,7 @@ public class GridP2PContinuousDeploymentTask2 extends ComputeTaskSplitAdapter<Ob
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+    @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return null;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath1.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath1.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath1.java
index 527c33d..322e6b7 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath1.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath1.java
@@ -38,7 +38,7 @@ public class GridP2PEventFilterExternalPath1 implements IgnitePredicate<IgniteEv
 
             ignite.message(ignite.cluster().forRemotes()).send(null, res);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new RuntimeException(e);
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath2.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath2.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath2.java
index abbfb51..15c1133 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath2.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PEventFilterExternalPath2.java
@@ -38,7 +38,7 @@ public class GridP2PEventFilterExternalPath2 implements IgnitePredicate<IgniteEv
 
             ignite.message(ignite.cluster().forRemotes()).send(null, res);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new RuntimeException(e);
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath1.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath1.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath1.java
index 44ea809..b9c6e9e 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath1.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath1.java
@@ -31,7 +31,7 @@ public class GridP2PTestTaskExternalPath1 extends ComputeTaskAdapter<Object, int
      * {@inheritDoc}
      */
     @SuppressWarnings({"unchecked"})
-    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
         if (log.isInfoEnabled()) {
             log.info("Mapping [task=" + this + ", subgrid=" + F.viewReadOnly(subgrid, F.node2id()) +
                 ", arg=" + arg + ']');
@@ -67,13 +67,13 @@ public class GridP2PTestTaskExternalPath1 extends ComputeTaskAdapter<Object, int
         if (!jobs.isEmpty())
             return jobs;
 
-        throw new GridException("Failed to find target node: " + arg);
+        throw new IgniteCheckedException("Failed to find target node: " + arg);
     }
 
     /**
      * {@inheritDoc}
      */
-    @Override public int[] reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public int[] reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return results.get(0).getData();
     }
 
@@ -123,7 +123,7 @@ public class GridP2PTestTaskExternalPath1 extends ComputeTaskAdapter<Object, int
         }
 
         /** {@inheritDoc} */
-        @Override public int[] execute() throws GridException {
+        @Override public int[] execute() throws IgniteCheckedException {
             assert locNodeId.equals(argument(0));
 
             log.info("Running job on node: " + g.cluster().localNode().id());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath2.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath2.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath2.java
index d7640ef..743eeb6 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath2.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridP2PTestTaskExternalPath2.java
@@ -31,7 +31,7 @@ public class GridP2PTestTaskExternalPath2 extends ComputeTaskAdapter<Object, int
      * {@inheritDoc}
      */
     @SuppressWarnings({"unchecked"})
-    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
         if (log.isInfoEnabled()) {
             log.info("Mapping [task=" + this + ", subgrid=" + F.viewReadOnly(subgrid, F.node2id()) +
                 ", arg=" + arg + ']');
@@ -67,13 +67,13 @@ public class GridP2PTestTaskExternalPath2 extends ComputeTaskAdapter<Object, int
         if (!jobs.isEmpty())
             return jobs;
 
-        throw new GridException("Failed to find target node: " + arg);
+        throw new IgniteCheckedException("Failed to find target node: " + arg);
     }
 
     /**
      * {@inheritDoc}
      */
-    @Override public int[] reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public int[] reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return results.get(0).getData();
     }
 
@@ -114,7 +114,7 @@ public class GridP2PTestTaskExternalPath2 extends ComputeTaskAdapter<Object, int
         /**
          * {@inheritDoc}
          */
-        @Override public int[] execute() throws GridException {
+        @Override public int[] execute() throws IgniteCheckedException {
             assert locNodeId.equals(argument(0));
 
             if (sleep) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridSingleSplitTestTask.java
----------------------------------------------------------------------
diff --git a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridSingleSplitTestTask.java b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridSingleSplitTestTask.java
index 44d5a4a..d54f078 100644
--- a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridSingleSplitTestTask.java
+++ b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridSingleSplitTestTask.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.tests.p2p;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.gridgain.grid.*;
 
@@ -22,7 +23,7 @@ public class GridSingleSplitTestTask extends ComputeTaskSplitAdapter<Integer, In
     /**
      * {@inheritDoc}
      */
-    @Override protected Collection<? extends ComputeJob> split(int gridSize, Integer arg) throws GridException {
+    @Override protected Collection<? extends ComputeJob> split(int gridSize, Integer arg) throws IgniteCheckedException {
         assert gridSize > 0 : "Subgrid cannot be empty.";
 
         Collection<ComputeJobAdapter> jobs = new ArrayList<>(gridSize);
@@ -36,7 +37,7 @@ public class GridSingleSplitTestTask extends ComputeTaskSplitAdapter<Integer, In
     /**
      * {@inheritDoc}
      */
-    @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         int retVal = 0;
 
         for (ComputeJobResult res : results) {
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperLoadTest1.java b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperLoadTest1.java
index 11462cb..02dcc04 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperLoadTest1.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperLoadTest1.java
@@ -21,9 +21,9 @@ public class GridContinuousMapperLoadTest1 {
      * Main method.
      *
      * @param args Parameters.
      * @throws GridException If failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = G.start("examples/config/example-cache.xml")) {
             int max = 30000;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask1.java
----------------------------------------------------------------------
@@ -21,9 +21,9 @@ public class GridContinuousMapperLoadTest1 {
      *
      * @param args Parameters.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask1.java b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask1.java
index 46dd7e7..88673d7 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask1.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask1.java
@@ -64,9 +64,9 @@ public class GridContinuousMapperTask1 extends ComputeTaskAdapter<Integer, Integ
      * Sends job to node.
      *
      * @param n Node.
      * @throws GridException If failed.
      */
-    private void sendJob(ClusterNode n) throws GridException {
+    private void sendJob(ClusterNode n) throws IgniteCheckedException {
         try {
             int jobId = queue.take();
 
@@ -86,13 +86,13 @@ public class GridContinuousMapperTask1 extends ComputeTaskAdapter<Integer, Integ
             }, n);
         }
         catch (InterruptedException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Integer arg)
-        throws GridException {
+        throws IgniteCheckedException {
         maxExecs = arg;
 
         // Start worker thread.
@@ -108,9 +108,9 @@ public class GridContinuousMapperTask1 extends ComputeTaskAdapter<Integer, Integ
     }
 
     /** {@inheritDoc} */
-    @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd) throws GridException {
+    @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd) throws IgniteCheckedException {
         if (res.getException() != null)
-            throw new GridException(res.getException());
+            throw new IgniteCheckedException(res.getException());
 
         TestObject o = res.getData();
 
@@ -125,7 +125,7 @@ public class GridContinuousMapperTask1 extends ComputeTaskAdapter<Integer, Integ
     }
 
     /** {@inheritDoc} */
-    @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         X.println(">>> Reducing task...");
 
         t.interrupt();
@@ -134,7 +134,7 @@ public class GridContinuousMapperTask1 extends ComputeTaskAdapter<Integer, Integ
             t.join();
         }
         catch (InterruptedException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
 
         return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridContinuousMapperTask2.java
----------------------------------------------------------------------
@@ -64,9 +64,9 @@ public class GridContinuousMapperTask1 extends ComputeTaskAdapter<Integer, Integ
      *
      * @param n Node.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridNodeStartup.java b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridNodeStartup.java
index 1aa3187..43008ac 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridNodeStartup.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/mapper/GridNodeStartup.java
@@ -29,9 +29,9 @@ public class GridNodeStartup {
      * Start up an empty node with specified cache configuration.
      *
      * @param args Command line arguments, none required.
      * @throws GridException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite ignored = G.start("examples/config/example-cache.xml")) {
             // Wait until Ok is pressed.
             JOptionPane.showMessageDialog(

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTask.java
----------------------------------------------------------------------
@@ -29,9 +29,9 @@ public class GridNodeStartup {
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTest.java b/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTest.java
index b2d188a..a888222 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTest.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/mergesort/GridMergeSortLoadTest.java
@@ -45,10 +45,10 @@ public class GridMergeSortLoadTest {
      *              <b>3-nd argument:</b> size of the generated array for "warm up" (optional, default: {@code 10000}).
      *          </li>
      *      </ul>
      * @throws GridException In case of error.
      * @throws IOException In case of file output error.
      */
-    public static void main(String[] args) throws GridException, IOException {
+    public static void main(String[] args) throws IgniteCheckedException, IOException {
         GridFileLock fileLock = GridLoadTestUtils.fileLock();
 
         fileLock.lock();
@@ -99,9 +99,9 @@ public class GridMergeSortLoadTest {
      * @param g Grid to run sorting on.
      * @param size Size of the generated array, which we sort.
      * @return Sort execution time in milliseconds.
      * @throws GridException If failed.
      */
-    private static long sort(Ignite g, int size) throws GridException {
+    private static long sort(Ignite g, int size) throws IgniteCheckedException {
         int[] bigArr = generateRandomArray(size);
 
         X.println("Array is generated.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/nio/GridNioBenchmarkTest.java
----------------------------------------------------------------------
@@ -45,10 +45,10 @@ public class GridMergeSortLoadTest {
      *          </li>
      *      </ul>
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws IOException In case of file output error.
      */
@@ -99,9 +99,9 @@ public class GridMergeSortLoadTest {
      * @param size Size of the generated array, which we sort.
      * @return Sort execution time in milliseconds.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/nio/GridNioBenchmarkTest.java b/modules/core/src/test/java/org/gridgain/loadtests/nio/GridNioBenchmarkTest.java
index 16ed442..87a1fd7 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/nio/GridNioBenchmarkTest.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/nio/GridNioBenchmarkTest.java
@@ -43,10 +43,10 @@ public class GridNioBenchmarkTest {
      * Runs the benchmark.
      *
      * @throws UnknownHostException If can't connect to given hist,
      * @throws GridException If NIO server initialisation failed.
      */
     @SuppressWarnings("ConstantConditions")
-    public void run() throws UnknownHostException, GridException {
+    public void run() throws UnknownHostException, IgniteCheckedException {
         GridNioServerListener<ByteBuffer> lsnr = new GridNioServerListenerAdapter<ByteBuffer>() {
             @Override public void onConnected(GridNioSession ses) {
                 X.print("New connection accepted.");
@@ -95,9 +95,9 @@ public class GridNioBenchmarkTest {
      *
      * @param args Command line arguments.
      * @throws UnknownHostException If can't connect to given hist,
      * @throws GridException If NIO server initialisation failed.
      */
-    public static void main(String[] args) throws UnknownHostException, GridException {
+    public static void main(String[] args) throws UnknownHostException, IgniteCheckedException {
         if (args.length != 2) {
             X.println("Usage: " + GridNioBenchmarkTest.class.getSimpleName() + " <threads> <port>");
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/streamer/EventClosure.java
----------------------------------------------------------------------
@@ -43,10 +43,10 @@ public class GridNioBenchmarkTest {
      *
      * @throws UnknownHostException If can't connect to given hist,
-     * @throws GridException If NIO server initialisation failed.
+     * @throws IgniteCheckedException If NIO server initialisation failed.
      */
     @SuppressWarnings("ConstantConditions")
@@ -95,9 +95,9 @@ public class GridNioBenchmarkTest {
      * @param args Command line arguments.
      * @throws UnknownHostException If can't connect to given hist,
-     * @throws GridException If NIO server initialisation failed.
+     * @throws IgniteCheckedException If NIO server initialisation failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/swap/GridSwapEvictAllBenchmark.java b/modules/core/src/test/java/org/gridgain/loadtests/swap/GridSwapEvictAllBenchmark.java
index b40384f..dea946e 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/swap/GridSwapEvictAllBenchmark.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/swap/GridSwapEvictAllBenchmark.java
@@ -238,9 +238,9 @@ public class GridSwapEvictAllBenchmark {
     /**
      * @param store Cache store.
      * @return Started grid.
      * @throws GridException If failed.
      */
-    private static Ignite start(GridCacheStore<Long, String> store) throws GridException {
+    private static Ignite start(GridCacheStore<Long, String> store) throws IgniteCheckedException {
         IgniteConfiguration cfg = new IgniteConfiguration();
 
         cfg.setLocalHost("127.0.0.1");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/loadtests/util/GridLoadTestArgs.java
----------------------------------------------------------------------
@@ -238,9 +238,9 @@ public class GridSwapEvictAllBenchmark {
      * @param store Cache store.
      * @return Started grid.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/loadtests/util/GridLoadTestArgs.java b/modules/core/src/test/java/org/gridgain/loadtests/util/GridLoadTestArgs.java
index f4abcb6..a68aa49 100644
--- a/modules/core/src/test/java/org/gridgain/loadtests/util/GridLoadTestArgs.java
+++ b/modules/core/src/test/java/org/gridgain/loadtests/util/GridLoadTestArgs.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.loadtests.util;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -150,16 +150,16 @@ public class GridLoadTestArgs {
      * @return JVM property value or environment variable value if
      *         JVM property is {@code null} or default value if both
      *         are {@code null}.
      * @throws GridException If the value didn't pass the validation.
      */
     public static int getIntProperty(String name, int dflt, IgniteClosure<Integer, String> validClo)
-        throws GridException {
+        throws IgniteCheckedException {
         int ret = getIntProperty(name, dflt);
 
         String errMsg = validClo.apply(ret);
 
         if (errMsg != null)
-            throw new GridException("Illegal value for " + name + " parameter: " + errMsg);
+            throw new IgniteCheckedException("Illegal value for " + name + " parameter: " + errMsg);
 
         return ret;
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/startup/GridRandomCommandLineLoader.java
----------------------------------------------------------------------
@@ -150,16 +150,16 @@ public class GridLoadTestArgs {
      *         JVM property is {@code null} or default value if both
      *         are {@code null}.
-     * @throws GridException If the value didn't pass the validation.
+     * @throws IgniteCheckedException If the value didn't pass the validation.
      */
     public static int getIntProperty(String name, int dflt, IgniteClosure<Integer, String> validClo)
diff --git a/modules/core/src/test/java/org/gridgain/startup/GridRandomCommandLineLoader.java b/modules/core/src/test/java/org/gridgain/startup/GridRandomCommandLineLoader.java
index 6419869..6769576 100644
--- a/modules/core/src/test/java/org/gridgain/startup/GridRandomCommandLineLoader.java
+++ b/modules/core/src/test/java/org/gridgain/startup/GridRandomCommandLineLoader.java
@@ -101,7 +101,7 @@ public final class GridRandomCommandLineLoader {
      *
      * @param e Exception to print.
      */
-    private static void echo(GridException e) {
+    private static void echo(IgniteCheckedException e) {
         assert e != null;
 
         System.err.println(e);
@@ -251,7 +251,7 @@ public final class GridRandomCommandLineLoader {
                 now = System.currentTimeMillis();
             }
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             echo(e);
 
             exit("Failed to start grid: " + e.getMessage(), null, -1);
@@ -279,21 +279,21 @@ public final class GridRandomCommandLineLoader {
      * @param springCfgPath Configuration file path.
      * @param logCfgPath Log file name.
      * @return List of configurations.
      * @throws GridException If an error occurs.
      */
     @SuppressWarnings("unchecked")
     private static IgniteConfiguration getConfiguration(String springCfgPath, @Nullable String logCfgPath)
-        throws GridException {
+        throws IgniteCheckedException {
         assert springCfgPath != null;
 
         File path = GridTestUtils.resolveGridGainPath(springCfgPath);
 
         if (path == null)
-            throw new GridException("Spring XML configuration file path is invalid: " + new File(springCfgPath) +
+            throw new IgniteCheckedException("Spring XML configuration file path is invalid: " + new File(springCfgPath) +
                 ". Note that this path should be either absolute path or a relative path to GRIDGAIN_HOME.");
 
         if (!path.isFile())
-            throw new GridException("Provided file path is not a file: " + path);
+            throw new IgniteCheckedException("Provided file path is not a file: " + path);
 
         // Add no-op logger to remove no-appender warning.
         Appender app = new NullAppender();
@@ -306,7 +306,7 @@ public final class GridRandomCommandLineLoader {
             springCtx = new FileSystemXmlApplicationContext(path.toURI().toURL().toString());
         }
         catch (BeansException | MalformedURLException e) {
-            throw new GridException("Failed to instantiate Spring XML application context: " + e.getMessage(), e);
+            throw new IgniteCheckedException("Failed to instantiate Spring XML application context: " + e.getMessage(), e);
         }
 
         Map cfgMap;
@@ -316,18 +316,18 @@ public final class GridRandomCommandLineLoader {
             cfgMap = springCtx.getBeansOfType(IgniteConfiguration.class);
         }
         catch (BeansException e) {
-            throw new GridException("Failed to instantiate bean [type=" + IgniteConfiguration.class + ", err=" +
+            throw new IgniteCheckedException("Failed to instantiate bean [type=" + IgniteConfiguration.class + ", err=" +
                 e.getMessage() + ']', e);
         }
 
         if (cfgMap == null)
-            throw new GridException("Failed to find a single grid factory configuration in: " + path);
+            throw new IgniteCheckedException("Failed to find a single grid factory configuration in: " + path);
 
         // Remove previously added no-op logger.
         Logger.getRootLogger().removeAppender(app);
 
         if (cfgMap.size() != 1)
-            throw new GridException("Spring configuration file should contain exactly 1 grid configuration: " + path);
+            throw new IgniteCheckedException("Spring configuration file should contain exactly 1 grid configuration: " + path);
 
         IgniteConfiguration cfg = (IgniteConfiguration)F.first(cfgMap.values());
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/startup/GridVmNodesStarter.java
----------------------------------------------------------------------
@@ -279,21 +279,21 @@ public final class GridRandomCommandLineLoader {
      * @param logCfgPath Log file name.
      * @return List of configurations.
-     * @throws GridException If an error occurs.
+     * @throws IgniteCheckedException If an error occurs.
      */
     @SuppressWarnings("unchecked")
diff --git a/modules/core/src/test/java/org/gridgain/startup/GridVmNodesStarter.java b/modules/core/src/test/java/org/gridgain/startup/GridVmNodesStarter.java
index 8399c95..a79dbfd 100644
--- a/modules/core/src/test/java/org/gridgain/startup/GridVmNodesStarter.java
+++ b/modules/core/src/test/java/org/gridgain/startup/GridVmNodesStarter.java
@@ -10,10 +10,10 @@
 package org.gridgain.startup;
 
 import org.apache.commons.cli.*;
+import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
 import org.apache.log4j.*;
 import org.apache.log4j.varia.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.*;
 import org.springframework.beans.*;
@@ -74,7 +74,7 @@ public final class GridVmNodesStarter {
      *
      * @param e Exception to print.
      */
-    private static void echo(GridException e) {
+    private static void echo(IgniteCheckedException e) {
         assert e != null;
 
         System.err.println(e);
@@ -110,9 +110,9 @@ public final class GridVmNodesStarter {
      * Main entry point.
      *
      * @param args Command line arguments.
      * @throws GridException If failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         System.setProperty(GG_UPDATE_NOTIFIER, "false");
 
         Options options = createOptions();
@@ -173,19 +173,19 @@ public final class GridVmNodesStarter {
      *
      * @param springCfgPath Configuration file path.
      * @return List of configurations.
      * @throws GridException If an error occurs.
      */
     @SuppressWarnings("unchecked")
     private static Iterable<IgniteConfiguration> getConfigurations(String springCfgPath)
-        throws GridException {
+        throws IgniteCheckedException {
         File path = GridTestUtils.resolveGridGainPath(springCfgPath);
 
         if (path == null)
-            throw new GridException("Spring XML configuration file path is invalid: " + new File(springCfgPath) +
+            throw new IgniteCheckedException("Spring XML configuration file path is invalid: " + new File(springCfgPath) +
                 ". Note that this path should be either absolute path or a relative path to GRIDGAIN_HOME.");
 
         if (!path.isFile())
-            throw new GridException("Provided file path is not a file: " + path);
+            throw new IgniteCheckedException("Provided file path is not a file: " + path);
 
         // Add no-op logger to remove no-appender warning.
         Appender app = new NullAppender();
@@ -198,7 +198,7 @@ public final class GridVmNodesStarter {
             springCtx = new FileSystemXmlApplicationContext(path.toURI().toURL().toString());
         }
         catch (BeansException | MalformedURLException e) {
-            throw new GridException("Failed to instantiate Spring XML application context: " + e.getMessage(), e);
+            throw new IgniteCheckedException("Failed to instantiate Spring XML application context: " + e.getMessage(), e);
         }
 
         Map cfgMap;
@@ -208,18 +208,18 @@ public final class GridVmNodesStarter {
             cfgMap = springCtx.getBeansOfType(IgniteConfiguration.class);
         }
         catch (BeansException e) {
-            throw new GridException("Failed to instantiate bean [type=" + IgniteConfiguration.class + ", err=" +
+            throw new IgniteCheckedException("Failed to instantiate bean [type=" + IgniteConfiguration.class + ", err=" +
                 e.getMessage() + ']', e);
         }
 
         if (cfgMap == null)
-            throw new GridException("Failed to find a single grid factory configuration in: " + path);
+            throw new IgniteCheckedException("Failed to find a single grid factory configuration in: " + path);
 
         // Remove previously added no-op logger.
         Logger.getRootLogger().removeAppender(app);
 
         if (cfgMap.isEmpty())
-            throw new GridException("Can't find grid factory configuration in: " + path);
+            throw new IgniteCheckedException("Can't find grid factory configuration in: " + path);
 
         Collection<IgniteConfiguration> res = new ArrayList<>();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/GridFileLock.java
----------------------------------------------------------------------
@@ -110,9 +110,9 @@ public final class GridVmNodesStarter {
      *
      * @param args Command line arguments.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -173,19 +173,19 @@ public final class GridVmNodesStarter {
      * @param springCfgPath Configuration file path.
      * @return List of configurations.
-     * @throws GridException If an error occurs.
+     * @throws IgniteCheckedException If an error occurs.
      */
     @SuppressWarnings("unchecked")
diff --git a/modules/core/src/test/java/org/gridgain/testframework/GridFileLock.java b/modules/core/src/test/java/org/gridgain/testframework/GridFileLock.java
index 14043ea..f083bf8 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/GridFileLock.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/GridFileLock.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.testframework;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
@@ -47,9 +47,9 @@ public class GridFileLock {
      * Performs an exclusive lock on a file, that
      * this lock instance was constructed with.
      *
      * @throws GridException If failed to perform locking. The file remains open.
      */
-    public void lock() throws GridException {
+    public void lock() throws IgniteCheckedException {
         lock(false);
     }
 
@@ -58,20 +58,20 @@ public class GridFileLock {
      * this lock instance was constructed with.
      *
      * @param shared Whether a lock is shared (non-exclusive).
      * @throws GridException If failed to perform locking. The file remains open.
      */
-    public void lock(boolean shared) throws GridException {
+    public void lock(boolean shared) throws IgniteCheckedException {
         if (fileLock != null)
-            throw new GridException("Already locked [lockFile=" + file + ']');
+            throw new IgniteCheckedException("Already locked [lockFile=" + file + ']');
 
         try {
             fileLock = raFile.getChannel().tryLock(0, Long.MAX_VALUE, shared);
 
             if (fileLock == null)
-                throw new GridException("Failed to get exclusive lock on lock file [lockFile=" + file + ']');
+                throw new IgniteCheckedException("Failed to get exclusive lock on lock file [lockFile=" + file + ']');
         }
         catch (IOException | OverlappingFileLockException e) {
-            throw new GridException("Failed to get exclusive lock on lock file [lockFile=" + file + ']', e);
+            throw new IgniteCheckedException("Failed to get exclusive lock on lock file [lockFile=" + file + ']', e);
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/GridGgfsTestUtils.java
----------------------------------------------------------------------
@@ -47,9 +47,9 @@ public class GridFileLock {
      * this lock instance was constructed with.
      *
-     * @throws GridException If failed to perform locking. The file remains open.
+     * @throws IgniteCheckedException If failed to perform locking. The file remains open.
      */
@@ -58,20 +58,20 @@ public class GridFileLock {
      *
      * @param shared Whether a lock is shared (non-exclusive).
-     * @throws GridException If failed to perform locking. The file remains open.
+     * @throws IgniteCheckedException If failed to perform locking. The file remains open.
      */
diff --git a/modules/core/src/test/java/org/gridgain/testframework/GridGgfsTestUtils.java b/modules/core/src/test/java/org/gridgain/testframework/GridGgfsTestUtils.java
index 7b273be..0fa12ef 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/GridGgfsTestUtils.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/GridGgfsTestUtils.java
@@ -10,7 +10,7 @@
 package org.gridgain.testframework;
 
 import net.sf.json.*;
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 import java.util.*;
 
@@ -23,9 +23,9 @@ public class GridGgfsTestUtils {
      *
      * @param jsonStr String to convert.
      * @return Map.
      * @throws GridException If fails.
      */
-    public static Map<String,String> jsonToMap(String jsonStr) throws GridException {
+    public static Map<String,String> jsonToMap(String jsonStr) throws IgniteCheckedException {
         Map<String,String> res = new HashMap<>();
 
         try {
@@ -39,7 +39,7 @@ public class GridGgfsTestUtils {
 
         }
         catch (JSONException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
 
         return res;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/GridSpiTestContext.java
----------------------------------------------------------------------
@@ -23,9 +23,9 @@ public class GridGgfsTestUtils {
      * @param jsonStr String to convert.
      * @return Map.
-     * @throws GridException If fails.
+     * @throws IgniteCheckedException If fails.
      */
diff --git a/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java b/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
index 9ef5a23..bdd7042 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
@@ -582,7 +582,7 @@ public final class GridTestUtils {
             final GridTestSafeThreadFactory thrFactory = new GridTestSafeThreadFactory("async-runner");
 
             final GridFutureAdapter<T> fut = new GridFutureAdapter<T>() {
-                @Override public boolean cancel() throws GridException {
+                @Override public boolean cancel() throws IgniteCheckedException {
                     super.cancel();
 
                     thrFactory.interruptAllThreads();
@@ -926,10 +926,10 @@ public final class GridTestUtils {
      * @param fieldName Field names to get value for.
      * @param <T> Expected field class.
      * @return Field value.
      * @throws GridRuntimeException In case of error.
      */
     @SuppressWarnings("SynchronizationOnLocalVariableOrMethodParameter")
-    public static <T> T getFieldValue(Object obj, Class cls, String fieldName) throws GridRuntimeException {
+    public static <T> T getFieldValue(Object obj, Class cls, String fieldName) throws IgniteException {
         assert obj != null;
         assert fieldName != null;
 
@@ -957,7 +957,7 @@ public final class GridTestUtils {
             return (T)obj;
         }
         catch (NoSuchFieldException | IllegalAccessException e) {
-            throw new GridRuntimeException("Failed to get object field [obj=" + obj +
+            throw new IgniteException("Failed to get object field [obj=" + obj +
                 ", fieldName=" + fieldName + ']', e);
         }
     }
@@ -969,10 +969,10 @@ public final class GridTestUtils {
      * @param fieldNames Field names to get value for: obj->field1->field2->...->fieldN.
      * @param <T> Expected field class.
      * @return Field value.
      * @throws GridRuntimeException In case of error.
      */
     @SuppressWarnings("SynchronizationOnLocalVariableOrMethodParameter")
-    public static <T> T getFieldValue(Object obj, String... fieldNames) throws GridRuntimeException {
+    public static <T> T getFieldValue(Object obj, String... fieldNames) throws IgniteException {
         assert obj != null;
         assert fieldNames != null;
         assert fieldNames.length >= 1;
@@ -1007,7 +1007,7 @@ public final class GridTestUtils {
                     Class<?> innerCls = getInnerClass(cls, fieldName);
 
                     if (innerCls == null)
-                        throw new GridRuntimeException("Failed to get object field [obj=" + obj +
+                        throw new IgniteException("Failed to get object field [obj=" + obj +
                             ", fieldNames=" + Arrays.toString(fieldNames) + ']', e);
 
                     obj = innerCls;
@@ -1017,7 +1017,7 @@ public final class GridTestUtils {
             return (T)obj;
         }
         catch (IllegalAccessException e) {
-            throw new GridRuntimeException("Failed to get object field [obj=" + obj +
+            throw new IgniteException("Failed to get object field [obj=" + obj +
                 ", fieldNames=" + Arrays.toString(fieldNames) + ']', e);
         }
     }
@@ -1043,10 +1043,10 @@ public final class GridTestUtils {
      * @param obj Object to set field value to.
      * @param fieldName Field name to set value for.
      * @param val New field value.
      * @throws GridRuntimeException In case of error.
      */
     @SuppressWarnings("SynchronizationOnLocalVariableOrMethodParameter")
-    public static void setFieldValue(Object obj, String fieldName, Object val) throws GridRuntimeException {
+    public static void setFieldValue(Object obj, String fieldName, Object val) throws IgniteException {
         assert obj != null;
         assert fieldName != null;
 
@@ -1073,7 +1073,7 @@ public final class GridTestUtils {
             }
         }
         catch (NoSuchFieldException | IllegalAccessException e) {
-            throw new GridRuntimeException("Failed to set object field [obj=" + obj + ", field=" + fieldName + ']', e);
+            throw new IgniteException("Failed to set object field [obj=" + obj + ", field=" + fieldName + ']', e);
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/junits/GridAbstractTest.java
----------------------------------------------------------------------
@@ -926,10 +926,10 @@ public final class GridTestUtils {
      * @param <T> Expected field class.
      * @return Field value.
-     * @throws GridRuntimeException In case of error.
+     * @throws IgniteException In case of error.
      */
     @SuppressWarnings("SynchronizationOnLocalVariableOrMethodParameter")
@@ -969,10 +969,10 @@ public final class GridTestUtils {
      * @param <T> Expected field class.
      * @return Field value.
-     * @throws GridRuntimeException In case of error.
+     * @throws IgniteException In case of error.
      */
     @SuppressWarnings("SynchronizationOnLocalVariableOrMethodParameter")
@@ -1043,10 +1043,10 @@ public final class GridTestUtils {
      * @param fieldName Field name to set value for.
      * @param val New field value.
-     * @throws GridRuntimeException In case of error.
+     * @throws IgniteException In case of error.
      */
     @SuppressWarnings("SynchronizationOnLocalVariableOrMethodParameter")
diff --git a/modules/core/src/test/java/org/gridgain/testframework/junits/GridAbstractTest.java b/modules/core/src/test/java/org/gridgain/testframework/junits/GridAbstractTest.java
index 212e075..570bc77 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/junits/GridAbstractTest.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/junits/GridAbstractTest.java
@@ -741,10 +741,10 @@ public abstract class GridAbstractTest extends TestCase {
     /**
      * @param ignite Grid
      * @param cnt Count
      * @throws GridException If failed.
      */
     @SuppressWarnings({"BusyWait"})
-    protected void waitForRemoteNodes(Ignite ignite, int cnt) throws GridException {
+    protected void waitForRemoteNodes(Ignite ignite, int cnt) throws IgniteCheckedException {
         while (true) {
             Collection<ClusterNode> nodes = ignite.cluster().forRemotes().nodes();
 
@@ -755,7 +755,7 @@ public abstract class GridAbstractTest extends TestCase {
                 Thread.sleep(100);
             }
             catch (InterruptedException ignored) {
-                throw new GridException("Interrupted while waiting for remote nodes [gridName=" + ignite.name() +
+                throw new IgniteCheckedException("Interrupted while waiting for remote nodes [gridName=" + ignite.name() +
                     ", count=" + cnt + ']');
             }
         }
@@ -763,9 +763,9 @@ public abstract class GridAbstractTest extends TestCase {
 
     /**
      * @param ignites Grids
      * @throws GridException If failed.
      */
-    protected void waitForDiscovery(Ignite... ignites) throws GridException {
+    protected void waitForDiscovery(Ignite... ignites) throws IgniteCheckedException {
         assert ignites != null;
         assert ignites.length > 1;
 
@@ -837,10 +837,10 @@ public abstract class GridAbstractTest extends TestCase {
      *
      * @param springCfgPath Path to file.
      * @return Grid configuration.
      * @throws GridException If load failed.
      */
     @SuppressWarnings("deprecation")
-    protected IgniteConfiguration loadConfiguration(String springCfgPath) throws GridException {
+    protected IgniteConfiguration loadConfiguration(String springCfgPath) throws IgniteCheckedException {
         URL cfgLocation = U.resolveGridGainUrl(springCfgPath);
 
         assert cfgLocation != null;
@@ -851,7 +851,7 @@ public abstract class GridAbstractTest extends TestCase {
             springCtx = new FileSystemXmlApplicationContext(cfgLocation.toString());
         }
         catch (BeansException e) {
-            throw new GridException("Failed to instantiate Spring XML application context.", e);
+            throw new IgniteCheckedException("Failed to instantiate Spring XML application context.", e);
         }
 
         Map cfgMap;
@@ -861,17 +861,17 @@ public abstract class GridAbstractTest extends TestCase {
             cfgMap = springCtx.getBeansOfType(IgniteConfiguration.class);
         }
         catch (BeansException e) {
-            throw new GridException("Failed to instantiate bean [type=" + IgniteConfiguration.class + ", err=" +
+            throw new IgniteCheckedException("Failed to instantiate bean [type=" + IgniteConfiguration.class + ", err=" +
                 e.getMessage() + ']', e);
         }
 
         if (cfgMap == null)
-            throw new GridException("Failed to find a single grid factory configuration in: " + springCfgPath);
+            throw new IgniteCheckedException("Failed to find a single grid factory configuration in: " + springCfgPath);
 
         if (cfgMap.isEmpty())
-            throw new GridException("Can't find grid factory configuration in: " + springCfgPath);
+            throw new IgniteCheckedException("Can't find grid factory configuration in: " + springCfgPath);
         else if (cfgMap.size() > 1)
-            throw new GridException("More than one configuration provided for cache load test: " + cfgMap.values());
+            throw new IgniteCheckedException("More than one configuration provided for cache load test: " + cfgMap.values());
 
         IgniteConfiguration cfg = (IgniteConfiguration)cfgMap.values().iterator().next();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestKernalContext.java
----------------------------------------------------------------------
@@ -741,10 +741,10 @@ public abstract class GridAbstractTest extends TestCase {
      * @param ignite Grid
      * @param cnt Count
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings({"BusyWait"})
@@ -763,9 +763,9 @@ public abstract class GridAbstractTest extends TestCase {
     /**
      * @param ignites Grids
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -837,10 +837,10 @@ public abstract class GridAbstractTest extends TestCase {
      * @param springCfgPath Path to file.
      * @return Grid configuration.
-     * @throws GridException If load failed.
+     * @throws IgniteCheckedException If load failed.
      */
     @SuppressWarnings("deprecation")
diff --git a/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestKernalContext.java b/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestKernalContext.java
index 0a922bc..fa5e4ed 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestKernalContext.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestKernalContext.java
@@ -45,9 +45,9 @@ public class GridTestKernalContext extends GridKernalContextImpl {
     /**
      * Starts everything added (in the added order).
      *
      * @throws GridException If failed
      */
-    public void start() throws GridException {
+    public void start() throws IgniteCheckedException {
         for (GridComponent comp : this)
             comp.start();
     }
@@ -56,9 +56,9 @@ public class GridTestKernalContext extends GridKernalContextImpl {
      * Stops everything added.
      *
      * @param cancel Cancel parameter.
      * @throws GridException If failed.
      */
-    public void stop(boolean cancel) throws GridException {
+    public void stop(boolean cancel) throws IgniteCheckedException {
         List<GridComponent> comps = components();
 
         for (ListIterator<GridComponent> it = comps.listIterator(comps.size()); it.hasPrevious();) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestResources.java
----------------------------------------------------------------------
@@ -45,9 +45,9 @@ public class GridTestKernalContext extends GridKernalContextImpl {
      * Starts everything added (in the added order).
      *
-     * @throws GridException If failed
+     * @throws IgniteCheckedException If failed
      */
@@ -56,9 +56,9 @@ public class GridTestKernalContext extends GridKernalContextImpl {
      *
      * @param cancel Cancel parameter.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestResources.java b/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestResources.java
index 7ce5bc1..8f8b4a8 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestResources.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/junits/GridTestResources.java
@@ -153,9 +153,9 @@ public class GridTestResources {
 
     /**
      * @param target Target.
      * @throws GridException If failed.
      */
-    public void inject(Object target) throws GridException {
+    public void inject(Object target) throws IgniteCheckedException {
         assert target != null;
         assert getLogger() != null;
         assert getNodeId() != null;
@@ -226,10 +226,10 @@ public class GridTestResources {
 
     /**
      * @return Marshaller.
      * @throws GridException If failed.
      */
     @SuppressWarnings("unchecked")
-    public synchronized IgniteMarshaller getMarshaller() throws GridException {
+    public synchronized IgniteMarshaller getMarshaller() throws IgniteCheckedException {
         if (marshaller == null) {
             String marshallerName = GridTestProperties.getProperty("marshaller.class");
 
@@ -242,7 +242,7 @@ public class GridTestResources {
                     marshaller = cls.newInstance();
                 }
                 catch (ClassNotFoundException | IllegalAccessException | InstantiationException e) {
-                    throw new GridException("Failed to create test marshaller [marshaller=" + marshallerName + ']', e);
+                    throw new IgniteCheckedException("Failed to create test marshaller [marshaller=" + marshallerName + ']', e);
                 }
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/junits/cache/GridAbstractCacheStoreSelfTest.java
----------------------------------------------------------------------
@@ -153,9 +153,9 @@ public class GridTestResources {
     /**
      * @param target Target.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -226,10 +226,10 @@ public class GridTestResources {
     /**
      * @return Marshaller.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings("unchecked")
diff --git a/modules/core/src/test/java/org/gridgain/testframework/junits/cache/GridAbstractCacheStoreSelfTest.java b/modules/core/src/test/java/org/gridgain/testframework/junits/cache/GridAbstractCacheStoreSelfTest.java
index a975820..2c56601 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/junits/cache/GridAbstractCacheStoreSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/junits/cache/GridAbstractCacheStoreSelfTest.java
@@ -9,12 +9,12 @@
 
 package org.gridgain.testframework.junits.cache;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.store.*;
-import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.lang.*;
+import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
@@ -69,9 +69,9 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
     }
 
     /**
      * @throws GridException if failed.
      */
-    public void testRollback() throws GridException {
+    public void testRollback() throws IgniteCheckedException {
         GridCacheTx tx = new DummyTx();
 
         // Put.
@@ -132,32 +132,32 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
     }
 
     /**
      * @throws GridException if failed.
      */
-    public void testAllOpsWithTXNoCommit() throws GridException {
+    public void testAllOpsWithTXNoCommit() throws IgniteCheckedException {
         doTestAllOps(new DummyTx(), false);
     }
 
     /**
      * @throws GridException if failed.
      */
-    public void testAllOpsWithTXCommit() throws GridException {
+    public void testAllOpsWithTXCommit() throws IgniteCheckedException {
         doTestAllOps(new DummyTx(), true);
     }
 
     /**
      * @throws GridException if failed.
      */
-    public void testAllOpsWithoutTX() throws GridException {
+    public void testAllOpsWithoutTX() throws IgniteCheckedException {
         doTestAllOps(null, false);
     }
 
     /**
      * @param tx Transaction.
      * @param commit Commit.
      * @throws GridException If failed.
      */
-    private void doTestAllOps(@Nullable GridCacheTx tx, boolean commit) throws GridException {
+    private void doTestAllOps(@Nullable GridCacheTx tx, boolean commit) throws IgniteCheckedException {
         try {
             store.put(tx, "key1", "val1");
 
@@ -473,12 +473,12 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
         }
 
         /** {@inheritDoc} */
-        @Override public void commit() throws GridException {
+        @Override public void commit() throws IgniteCheckedException {
             // No-op.
         }
 
         /** {@inheritDoc} */
-        @Override public void close() throws GridException {
+        @Override public void close() throws IgniteCheckedException {
             // No-op.
         }
 
@@ -488,7 +488,7 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
         }
 
         /** {@inheritDoc} */
-        @Override public void rollback() throws GridException {
+        @Override public void rollback() throws IgniteCheckedException {
             // No-op.
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/junits/common/GridCommonAbstractTest.java
----------------------------------------------------------------------
@@ -69,9 +69,9 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
 
     /**
-     * @throws GridException if failed.
+     * @throws IgniteCheckedException if failed.
      */
@@ -132,32 +132,32 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
 
     /**
-     * @throws GridException if failed.
+     * @throws IgniteCheckedException if failed.
      */
@@ -132,32 +132,32 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
 
     /**
-     * @throws GridException if failed.
+     * @throws IgniteCheckedException if failed.
      */
@@ -132,32 +132,32 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
 
     /**
-     * @throws GridException if failed.
+     * @throws IgniteCheckedException if failed.
      */
@@ -132,32 +132,32 @@ public abstract class GridAbstractCacheStoreSelfTest<T extends GridCacheStore<Ob
      * @param tx Transaction.
      * @param commit Commit.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/testframework/junits/common/GridCommonAbstractTest.java b/modules/core/src/test/java/org/gridgain/testframework/junits/common/GridCommonAbstractTest.java
index 176831d..095d05a 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/junits/common/GridCommonAbstractTest.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/junits/common/GridCommonAbstractTest.java
@@ -276,10 +276,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
     /**
      * @param cache Cache.
      * @return Collection of keys for which given cache is primary.
      * @throws GridException If failed.
      */
     protected Integer primaryKey(GridCacheProjection<Integer, ?> cache)
-        throws GridException {
+        throws IgniteCheckedException {
         return primaryKeys(cache, 1, 1).get(0);
     }
 
@@ -287,10 +287,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cache Cache.
      * @param cnt Keys count.
      * @return Collection of keys for which given cache is primary.
      * @throws GridException If failed.
      */
     protected List<Integer> primaryKeys(GridCacheProjection<Integer, ?> cache, int cnt)
-        throws GridException {
+        throws IgniteCheckedException {
         return primaryKeys(cache, cnt, 1);
     }
 
@@ -299,10 +299,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cnt Keys count.
      * @param startFrom Start value for keys search.
      * @return Collection of keys for which given cache is primary.
      * @throws GridException If failed.
      */
     protected List<Integer> primaryKeys(GridCacheProjection<Integer, ?> cache, int cnt, int startFrom)
-        throws GridException {
+        throws IgniteCheckedException {
         List<Integer> found = new ArrayList<>(cnt);
 
         ClusterNode locNode = cache.gridProjection().ignite().cluster().localNode();
@@ -320,16 +320,16 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
             }
         }
 
-        throw new GridException("Unable to find " + cnt + " keys as primary for cache.");
+        throw new IgniteCheckedException("Unable to find " + cnt + " keys as primary for cache.");
     }
 
     /**
      * @param cache Cache.
      * @return Collection of keys for which given cache is backup.
      * @throws GridException If failed.
      */
     protected Integer backupKey(GridCacheProjection<Integer, ?> cache)
-        throws GridException {
+        throws IgniteCheckedException {
         return backupKeys(cache, 1, 1).get(0);
     }
 
@@ -337,10 +337,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cache Cache.
      * @param cnt Keys count.
      * @return Collection of keys for which given cache is backup.
      * @throws GridException If failed.
      */
     protected List<Integer> backupKeys(GridCacheProjection<Integer, ?> cache, int cnt)
-        throws GridException {
+        throws IgniteCheckedException {
         return backupKeys(cache, cnt, 1);
     }
 
@@ -349,10 +349,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cnt Keys count.
      * @param startFrom Start value for keys search.
      * @return Collection of keys for which given cache is backup.
      * @throws GridException If failed.
      */
     protected List<Integer> backupKeys(GridCacheProjection<Integer, ?> cache, int cnt, int startFrom)
-        throws GridException {
+        throws IgniteCheckedException {
         List<Integer> found = new ArrayList<>(cnt);
 
         ClusterNode locNode = cache.gridProjection().ignite().cluster().localNode();
@@ -370,16 +370,16 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
             }
         }
 
-        throw new GridException("Unable to find " + cnt + " keys as backup for cache.");
+        throw new IgniteCheckedException("Unable to find " + cnt + " keys as backup for cache.");
     }
 
     /**
      * @param cache Cache.
      * @return Collection of keys for which given cache is neither primary nor backup.
      * @throws GridException If failed.
      */
     protected Integer nearKey(GridCacheProjection<Integer, ?> cache)
-        throws GridException {
+        throws IgniteCheckedException {
         return nearKeys(cache, 1, 1).get(0);
     }
 
@@ -387,10 +387,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cache Cache.
      * @param cnt Keys count.
      * @return Collection of keys for which given cache is neither primary nor backup.
      * @throws GridException If failed.
      */
     protected List<Integer> nearKeys(GridCacheProjection<Integer, ?> cache, int cnt)
-        throws GridException {
+        throws IgniteCheckedException {
         return nearKeys(cache, cnt, 1);
     }
 
@@ -399,10 +399,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cnt Keys count.
      * @param startFrom Start value for keys search.
      * @return Collection of keys for which given cache is neither primary nor backup.
      * @throws GridException If failed.
      */
     protected List<Integer> nearKeys(GridCacheProjection<Integer, ?> cache, int cnt, int startFrom)
-        throws GridException {
+        throws IgniteCheckedException {
         List<Integer> found = new ArrayList<>(cnt);
 
         ClusterNode locNode = cache.gridProjection().ignite().cluster().localNode();
@@ -420,7 +420,7 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
             }
         }
 
-        throw new GridException("Unable to find " + cnt + " keys as backup for cache.");
+        throw new IgniteCheckedException("Unable to find " + cnt + " keys as backup for cache.");
     }
 
     /**
@@ -428,10 +428,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param task Task.
      * @param arg Task argument.
      * @return Task future.
      * @throws GridException If failed.
      */
     protected <R> ComputeTaskFuture<R> executeAsync(IgniteCompute comp, ComputeTask task, @Nullable Object arg)
-        throws GridException {
+        throws IgniteCheckedException {
         comp = comp.enableAsync();
 
         assertNull(comp.execute(task, arg));
@@ -448,10 +448,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param taskName Task name.
      * @param arg Task argument.
      * @return Task future.
      * @throws GridException If failed.
      */
     protected <R> ComputeTaskFuture<R> executeAsync(IgniteCompute comp, String taskName, @Nullable Object arg)
-        throws GridException {
+        throws IgniteCheckedException {
         comp = comp.enableAsync();
 
         assertNull(comp.execute(taskName, arg));
@@ -468,11 +468,11 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param taskCls Task class.
      * @param arg Task argument.
      * @return Task future.
      * @throws GridException If failed.
      */
     @SuppressWarnings("unchecked")
     protected <R> ComputeTaskFuture<R> executeAsync(IgniteCompute comp, Class taskCls, @Nullable Object arg)
-        throws GridException {
+        throws IgniteCheckedException {
         comp = comp.enableAsync();
 
         assertNull(comp.execute(taskCls, arg));
@@ -489,10 +489,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param filter Filter.
      * @param types Events types.
      * @return Future.
      * @throws GridException If failed.
      */
     protected <T extends IgniteEvent> IgniteFuture<T> waitForLocalEvent(IgniteEvents evts,
-        @Nullable IgnitePredicate<T> filter, @Nullable int... types) throws GridException {
+        @Nullable IgnitePredicate<T> filter, @Nullable int... types) throws IgniteCheckedException {
         evts = evts.enableAsync();
 
         assertTrue(evts.isAsync());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/testframework/junits/logger/GridTestLog4jLogger.java
----------------------------------------------------------------------
@@ -276,10 +276,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cache Cache.
      * @return Collection of keys for which given cache is primary.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected Integer primaryKey(GridCacheProjection<Integer, ?> cache)
@@ -287,10 +287,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cnt Keys count.
      * @return Collection of keys for which given cache is primary.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected List<Integer> primaryKeys(GridCacheProjection<Integer, ?> cache, int cnt)
@@ -299,10 +299,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param startFrom Start value for keys search.
      * @return Collection of keys for which given cache is primary.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected List<Integer> primaryKeys(GridCacheProjection<Integer, ?> cache, int cnt, int startFrom)
@@ -320,16 +320,16 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cache Cache.
      * @return Collection of keys for which given cache is backup.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected Integer backupKey(GridCacheProjection<Integer, ?> cache)
@@ -337,10 +337,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cnt Keys count.
      * @return Collection of keys for which given cache is backup.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected List<Integer> backupKeys(GridCacheProjection<Integer, ?> cache, int cnt)
@@ -349,10 +349,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param startFrom Start value for keys search.
      * @return Collection of keys for which given cache is backup.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected List<Integer> backupKeys(GridCacheProjection<Integer, ?> cache, int cnt, int startFrom)
@@ -370,16 +370,16 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cache Cache.
      * @return Collection of keys for which given cache is neither primary nor backup.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected Integer nearKey(GridCacheProjection<Integer, ?> cache)
@@ -387,10 +387,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param cnt Keys count.
      * @return Collection of keys for which given cache is neither primary nor backup.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected List<Integer> nearKeys(GridCacheProjection<Integer, ?> cache, int cnt)
@@ -399,10 +399,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param startFrom Start value for keys search.
      * @return Collection of keys for which given cache is neither primary nor backup.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected List<Integer> nearKeys(GridCacheProjection<Integer, ?> cache, int cnt, int startFrom)
@@ -428,10 +428,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param arg Task argument.
      * @return Task future.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected <R> ComputeTaskFuture<R> executeAsync(IgniteCompute comp, ComputeTask task, @Nullable Object arg)
@@ -448,10 +448,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param arg Task argument.
      * @return Task future.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected <R> ComputeTaskFuture<R> executeAsync(IgniteCompute comp, String taskName, @Nullable Object arg)
@@ -468,11 +468,11 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param arg Task argument.
      * @return Task future.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings("unchecked")
@@ -489,10 +489,10 @@ public abstract class GridCommonAbstractTest extends GridAbstractTest {
      * @param types Events types.
      * @return Future.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected <T extends IgniteEvent> IgniteFuture<T> waitForLocalEvent(IgniteEvents evts,
diff --git a/modules/core/src/test/java/org/gridgain/testframework/junits/logger/GridTestLog4jLogger.java b/modules/core/src/test/java/org/gridgain/testframework/junits/logger/GridTestLog4jLogger.java
index b47edeb..c46d6a5 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/junits/logger/GridTestLog4jLogger.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/junits/logger/GridTestLog4jLogger.java
@@ -150,18 +150,18 @@ public class GridTestLog4jLogger extends GridMetadataAwareAdapter implements Ign
      * Creates new logger with given configuration {@code path}.
      *
      * @param path Path to log4j configuration XML file.
      * @throws GridException Thrown in case logger can't be created.
      */
-    public GridTestLog4jLogger(String path) throws GridException {
+    public GridTestLog4jLogger(String path) throws IgniteCheckedException {
         if (path == null)
-            throw new GridException("Configuration XML file for Log4j must be specified.");
+            throw new IgniteCheckedException("Configuration XML file for Log4j must be specified.");
 
         this.path = path;
 
         final URL cfgUrl = U.resolveGridGainUrl(path);
 
         if (cfgUrl == null)
-            throw new GridException("Log4j configuration path was not found: " + path);
+            throw new IgniteCheckedException("Log4j configuration path was not found: " + path);
 
         addConsoleAppenderIfNeeded(null, new C1<Boolean, Logger>() {
             @Override public Logger apply(Boolean init) {
@@ -179,14 +179,14 @@ public class GridTestLog4jLogger extends GridMetadataAwareAdapter implements Ign
      * Creates new logger with given configuration {@code cfgFile}.
      *
      * @param cfgFile Log4j configuration XML file.
      * @throws GridException Thrown in case logger can't be created.
      */
-    public GridTestLog4jLogger(File cfgFile) throws GridException {
+    public GridTestLog4jLogger(File cfgFile) throws IgniteCheckedException {
         if (cfgFile == null)
-            throw new GridException("Configuration XML file for Log4j must be specified.");
+            throw new IgniteCheckedException("Configuration XML file for Log4j must be specified.");
 
         if (!cfgFile.exists() || cfgFile.isDirectory())
-            throw new GridException("Log4j configuration path was not found or is a directory: " + cfgFile);
+            throw new IgniteCheckedException("Log4j configuration path was not found or is a directory: " + cfgFile);
 
         path = cfgFile.getAbsolutePath();
 
@@ -206,11 +206,11 @@ public class GridTestLog4jLogger extends GridMetadataAwareAdapter implements Ign
      * Creates new logger with given configuration {@code cfgUrl}.
      *
      * @param cfgUrl URL for Log4j configuration XML file.
      * @throws GridException Thrown in case logger can't be created.
      */
-    public GridTestLog4jLogger(final URL cfgUrl) throws GridException {
+    public GridTestLog4jLogger(final URL cfgUrl) throws IgniteCheckedException {
         if (cfgUrl == null)
-            throw new GridException("Configuration XML file for Log4j must be specified.");
+            throw new IgniteCheckedException("Configuration XML file for Log4j must be specified.");
 
         path = null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/email/src/main/java/org/gridgain/grid/kernal/processors/email/GridEmailProcessor.java
----------------------------------------------------------------------
@@ -150,18 +150,18 @@ public class GridTestLog4jLogger extends GridMetadataAwareAdapter implements Ign
      *
      * @param path Path to log4j configuration XML file.
-     * @throws GridException Thrown in case logger can't be created.
+     * @throws IgniteCheckedException Thrown in case logger can't be created.
      */
@@ -179,14 +179,14 @@ public class GridTestLog4jLogger extends GridMetadataAwareAdapter implements Ign
      *
      * @param cfgFile Log4j configuration XML file.
-     * @throws GridException Thrown in case logger can't be created.
+     * @throws IgniteCheckedException Thrown in case logger can't be created.
      */
@@ -206,11 +206,11 @@ public class GridTestLog4jLogger extends GridMetadataAwareAdapter implements Ign
      *
      * @param cfgUrl URL for Log4j configuration XML file.
-     * @throws GridException Thrown in case logger can't be created.
+     * @throws IgniteCheckedException Thrown in case logger can't be created.
      */
diff --git a/modules/email/src/main/java/org/gridgain/grid/kernal/processors/email/GridEmailProcessor.java b/modules/email/src/main/java/org/gridgain/grid/kernal/processors/email/GridEmailProcessor.java
index f25755d..a2e7b27 100644
--- a/modules/email/src/main/java/org/gridgain/grid/kernal/processors/email/GridEmailProcessor.java
+++ b/modules/email/src/main/java/org/gridgain/grid/kernal/processors/email/GridEmailProcessor.java
@@ -9,13 +9,13 @@
 
 package org.gridgain.grid.kernal.processors.email;
 
+import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.thread.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.future.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.worker.*;
 
 import javax.mail.*;
@@ -68,7 +68,7 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
 
                                 email.future().onDone(true);
                             }
-                            catch (GridException e) {
+                            catch (IgniteCheckedException e) {
                                 U.error(log, "Failed to send email with subject: " + email.subject(), e);
 
                                 email.future().onDone(e);
@@ -80,7 +80,7 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         if (isSmtpEnabled) {
             assert q == null;
             assert snd == null;
@@ -97,7 +97,7 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void stop(boolean cancel) throws GridException {
+    @Override public void stop(boolean cancel) throws IgniteCheckedException {
         if (isSmtpEnabled) {
             U.interrupt(snd);
             U.join(snd, log);
@@ -119,7 +119,7 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void sendNow(String subj, String body, boolean html) throws GridException {
+    @Override public void sendNow(String subj, String body, boolean html) throws IgniteCheckedException {
         String[] addrs = ctx.config().getAdminEmails();
 
         if (addrs != null && addrs.length > 0)
@@ -128,7 +128,7 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
 
     /** {@inheritDoc} */
     @Override public void sendNow(String subj, String body, boolean html, Collection<String> addrs)
-        throws GridException {
+        throws IgniteCheckedException {
         assert subj != null;
         assert body != null;
         assert addrs != null;
@@ -219,11 +219,11 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
      * @param body Email body.
      * @param html HTML format flag.
      * @param addrs Addresses to send email to.
      * @throws GridException Thrown in case when sending email failed.
      */
     public static void sendEmail(String smtpHost, int smtpPort, boolean ssl, boolean startTls, final String username,
         final String pwd, String from, String subj, String body, boolean html, Collection<String> addrs)
-        throws GridException {
+        throws IgniteCheckedException {
         assert smtpHost != null;
         assert smtpPort > 0;
         assert from != null;
@@ -283,7 +283,7 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
             Transport.send(email);
         }
         catch (MessagingException e) {
-            throw new GridException("Failed to send email.", e);
+            throw new IgniteCheckedException("Failed to send email.", e);
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
----------------------------------------------------------------------
@@ -219,11 +219,11 @@ public class GridEmailProcessor extends GridEmailProcessorAdapter {
      * @param html HTML format flag.
      * @param addrs Addresses to send email to.
-     * @throws GridException Thrown in case when sending email failed.
+     * @throws IgniteCheckedException Thrown in case when sending email failed.
      */
     public static void sendEmail(String smtpHost, int smtpPort, boolean ssl, boolean startTls, final String username,